Body

Struct Body 

pub struct Body(/* private fields */);
Response/request body. Body::from(bytes), Body::from("text"), etc. The body type used in axum requests and responses.

Implementations

Source

impl Body

pub fn new<B>(body: B) -> Body
where B: Body<Data = Bytes> + Send + 'static, <B as Body>::Error: Into<Box<dyn Error + Sync + Send>>,

Create a new Body that wraps another http_body::Body.

pub fn empty() -> Body

Create an empty body.

pub fn from_stream<S>(stream: S) -> Body
where S: TryStream + Send + 'static, <S as TryStream>::Ok: Into<Bytes>, <S as TryStream>::Error: Into<Box<dyn Error + Sync + Send>>,

Create a new Body from a Stream.

pub fn into_data_stream(self) -> BodyDataStream

Convert the body into a Stream of data frames.

Non-data frames (such as trailers) will be discarded. Use http_body_util::BodyStream if you need a Stream of all frame types.