RequestParts

Struct RequestParts 

pub struct RequestParts {
    pub method: Method,
    pub uri: Uri,
    pub version: Version,
    pub headers: HeaderMap,
    pub extensions: Extensions,
    /* private fields */
}
Decomposed request head (method, uri, headers, …). Named in the BoundaryFilter trait, so it must be reachable without axum.

Component parts of an HTTP Request

The HTTP request head consists of a method, uri, version, and a set of header fields.

Fields

method: Method

The request’s method

uri: Uri

The request’s URI

version: Version

The request’s version

headers: HeaderMap

The request’s headers

extensions: Extensions

The request’s extensions