pub struct RequestParts {
pub method: Method,
pub uri: Uri,
pub version: Version,
pub headers: HeaderMap,
pub extensions: Extensions,
/* private fields */
}Expand description
Decomposed request head (method, uri, headers, …). Named in the
BoundaryFilter trait, so it must be reachable without axum.
Component parts of an HTTP Request
The HTTP request head consists of a method, uri, version, and a set of header fields.
Fields
method: MethodThe request’s method
uri: UriThe request’s URI
version: VersionThe request’s version
headers: HeaderMapThe request’s headers
extensions: ExtensionsThe request’s extensions